==> tool-sql-2.3.1-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/ProvidedOperationBodyImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.instanceloading.AttributeChangedDelta;
import io.ciera.runtime.instanceloading.InstanceCreatedDelta;
import io.ciera.runtime.summit.application.IRunContext;
import io.ciera.runtime.summit.classes.IInstanceIdentifier;
import io.ciera.runtime.summit.classes.InstanceIdentifier;
import io.ciera.runtime.summit.classes.ModelInstance;
import io.ciera.runtime.summit.exceptions.EmptyInstanceException;
import io.ciera.runtime.summit.exceptions.InstancePopulationException;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.IWhere;
import io.ciera.runtime.summit.types.IXtumlType;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.ooaofooa.body.Body;
import io.ciera.tool.sql.ooaofooa.body.ProvidedOperationBody;
import io.ciera.tool.sql.ooaofooa.body.impl.BodyImpl;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedOperation;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl.ProvidedOperationImpl;


public class ProvidedOperationBodyImpl extends ModelInstance<ProvidedOperationBody,Sql> implements ProvidedOperationBody {

    public static final String KEY_LETTERS = "ACT_POB";
    public static final ProvidedOperationBody EMPTY_PROVIDEDOPERATIONBODY = new EmptyProvidedOperationBody();

    private Sql context;

    // constructors
    private ProvidedOperationBodyImpl( Sql context ) {
        this.context = context;
        ref_Action_ID = UniqueId.random();
        ref_Id = UniqueId.random();
        R687_specifies_processing_for_ProvidedOperation_inst = ProvidedOperationImpl.EMPTY_PROVIDEDOPERATION;
        R698_is_a_Body_inst = BodyImpl.EMPTY_BODY;
    }

    private ProvidedOperationBodyImpl( Sql context, UniqueId instanceId, UniqueId ref_Action_ID, UniqueId ref_Id ) {
        super(instanceId);
        this.context = context;
        this.ref_Action_ID = ref_Action_ID;
        this.ref_Id = ref_Id;
        R687_specifies_processing_for_ProvidedOperation_inst = ProvidedOperationImpl.EMPTY_PROVIDEDOPERATION;
        R698_is_a_Body_inst = BodyImpl.EMPTY_BODY;
    }

    public static ProvidedOperationBody create( Sql context ) throws XtumlException {
        ProvidedOperationBody newProvidedOperationBody = new ProvidedOperationBodyImpl( context );
        if ( context.addInstance( newProvidedOperationBody ) ) {
            newProvidedOperationBody.getRunContext().addChange(new InstanceCreatedDelta(newProvidedOperationBody, KEY_LETTERS));
            return newProvidedOperationBody;
        }
        else throw new InstancePopulationException( "Instance already exists within this population." );
    }

    public static ProvidedOperationBody create( Sql context, UniqueId instanceId, UniqueId ref_Action_ID, UniqueId ref_Id ) throws XtumlException {
        ProvidedOperationBody newProvidedOperationBody = new ProvidedOperationBodyImpl( context, instanceId, ref_Action_ID, ref_Id );
        if ( context.addInstance( newProvidedOperationBody ) ) {
            return newProvidedOperationBody;
        }
        else throw new InstancePopulationException( "Instance already exists within this population." );
    }



    // attributes
    private UniqueId ref_Action_ID;
    @Override
    public void setAction_ID(UniqueId ref_Action_ID) throws XtumlException {
        checkLiving();
        if (ref_Action_ID.inequality( this.ref_Action_ID)) {
            final UniqueId oldValue = this.ref_Action_ID;
            this.ref_Action_ID = ref_Action_ID;
            getRunContext().addChange(new AttributeChangedDelta(this, KEY_LETTERS, "ref_Action_ID", oldValue, this.ref_Action_ID));
        }
    }
    @Override
    public UniqueId getAction_ID() throws XtumlException {
        checkLiving();
        return ref_Action_ID;
    }
    private UniqueId ref_Id;
    @Override
    public UniqueId getId() throws XtumlException {
        checkLiving();
        return ref_Id;
    }
    @Override
    public void setId(UniqueId ref_Id) throws XtumlException {
        checkLiving();
        if (ref_Id.inequality( this.ref_Id)) {
            final UniqueId oldValue = this.ref_Id;
            this.ref_Id = ref_Id;
            getRunContext().addChange(new AttributeChangedDelta(this, KEY_LETTERS, "ref_Id", oldValue, this.ref_Id));
        }
    }


    // instance identifiers
    @Override
    public IInstanceIdentifier getId1() {
        try {
            return new InstanceIdentifier(getAction_ID());
        }
        catch ( XtumlException e ) {
            getRunContext().getLog().error(e);
            System.exit(1);
            return null;
        }
    }

    // operations


    // static operations


    // events


    // selections
    private ProvidedOperation R687_specifies_processing_for_ProvidedOperation_inst;
    @Override
    public void setR687_specifies_processing_for_ProvidedOperation( ProvidedOperation inst ) {
        R687_specifies_processing_for_ProvidedOperation_inst = inst;
    }
    @Override
    public ProvidedOperation R687_specifies_processing_for_ProvidedOperation() throws XtumlException {
        return R687_specifies_processing_for_ProvidedOperation_inst;
    }
    private Body R698_is_a_Body_inst;
    @Override
    public void setR698_is_a_Body( Body inst ) {
        R698_is_a_Body_inst = inst;
    }
    @Override
    public Body R698_is_a_Body() throws XtumlException {
        return R698_is_a_Body_inst;
    }


    @Override
    public IRunContext getRunContext() {
        return context().getRunContext();
    }

    @Override
    public Sql context() {
        return context;
    }

    @Override
    public String getKeyLetters() {
        return KEY_LETTERS;
    }

    @Override
    public ProvidedOperationBody self() {
        return this;
    }

    @Override
    public ProvidedOperationBody oneWhere(IWhere<IXtumlType> condition) throws XtumlException {
        if (null == condition) throw new XtumlException("Null condition passed to selection.");
        if (condition.evaluate(this)) return this;
        else return EMPTY_PROVIDEDOPERATIONBODY;
    }

}

class EmptyProvidedOperationBody extends ModelInstance<ProvidedOperationBody,Sql> implements ProvidedOperationBody {

    // attributes
    public void setAction_ID( UniqueId ref_Action_ID ) throws XtumlException {
        throw new EmptyInstanceException( "Cannot set attribute of empty instance." );
    }
    public UniqueId getAction_ID() throws XtumlException {
        throw new EmptyInstanceException( "Cannot get attribute of empty instance." );
    }
    public UniqueId getId() throws XtumlException {
        throw new EmptyInstanceException( "Cannot get attribute of empty instance." );
    }
    public void setId( UniqueId ref_Id ) throws XtumlException {
        throw new EmptyInstanceException( "Cannot set attribute of empty instance." );
    }


    // operations


    // selections
    @Override
    public ProvidedOperation R687_specifies_processing_for_ProvidedOperation() {
        return ProvidedOperationImpl.EMPTY_PROVIDEDOPERATION;
    }
    @Override
    public Body R698_is_a_Body() {
        return BodyImpl.EMPTY_BODY;
    }


    @Override
    public String getKeyLetters() {
        return ProvidedOperationBodyImpl.KEY_LETTERS;
    }

    @Override
    public ProvidedOperationBody self() {
        return this;
    }

    @Override
    public boolean isEmpty() {
        return true;
    }

    @Override
    public ProvidedOperationBody oneWhere(IWhere<IXtumlType> condition) throws XtumlException {
        if (null == condition) throw new XtumlException("Null condition passed to selection.");
        return ProvidedOperationBodyImpl.EMPTY_PROVIDEDOPERATIONBODY;
    }

}

==> tool-sql-2.6.0-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/ProvidedOperationBodyImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.instanceloading.AttributeChangedDelta;
import io.ciera.runtime.instanceloading.InstanceCreatedDelta;
import io.ciera.runtime.summit.application.IRunContext;
import io.ciera.runtime.summit.classes.IInstanceIdentifier;
import io.ciera.runtime.summit.classes.InstanceIdentifier;
import io.ciera.runtime.summit.classes.ModelInstance;
import io.ciera.runtime.summit.exceptions.EmptyInstanceException;
import io.ciera.runtime.summit.exceptions.InstancePopulationException;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.IWhere;
import io.ciera.runtime.summit.types.IXtumlType;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.ooaofooa.body.Body;
import io.ciera.tool.sql.ooaofooa.body.ProvidedOperationBody;
import io.ciera.tool.sql.ooaofooa.body.impl.BodyImpl;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedOperation;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl.ProvidedOperationImpl;


public class ProvidedOperationBodyImpl extends ModelInstance<ProvidedOperationBody,Sql> implements ProvidedOperationBody {

    public static final String KEY_LETTERS = "ACT_POB";
    public static final ProvidedOperationBody EMPTY_PROVIDEDOPERATIONBODY = new EmptyProvidedOperationBody();

    private Sql context;

    // constructors
    private ProvidedOperationBodyImpl( Sql context ) {
        this.context = context;
        ref_Action_ID = UniqueId.random();
        ref_Id = UniqueId.random();
        R687_specifies_processing_for_ProvidedOperation_inst = ProvidedOperationImpl.EMPTY_PROVIDEDOPERATION;
        R698_is_a_Body_inst = BodyImpl.EMPTY_BODY;
    }

    private ProvidedOperationBodyImpl( Sql context, UniqueId instanceId, UniqueId ref_Action_ID, UniqueId ref_Id ) {
        super(instanceId);
        this.context = context;
        this.ref_Action_ID = ref_Action_ID;
        this.ref_Id = ref_Id;
        R687_specifies_processing_for_ProvidedOperation_inst = ProvidedOperationImpl.EMPTY_PROVIDEDOPERATION;
        R698_is_a_Body_inst = BodyImpl.EMPTY_BODY;
    }

    public static ProvidedOperationBody create( Sql context ) throws XtumlException {
        ProvidedOperationBody newProvidedOperationBody = new ProvidedOperationBodyImpl( context );
        if ( context.addInstance( newProvidedOperationBody ) ) {
            newProvidedOperationBody.getRunContext().addChange(new InstanceCreatedDelta(newProvidedOperationBody, KEY_LETTERS));
            return newProvidedOperationBody;
        }
        else throw new InstancePopulationException( "Instance already exists within this population." );
    }

    public static ProvidedOperationBody create( Sql context, UniqueId ref_Action_ID, UniqueId ref_Id ) throws XtumlException {
        return create(context, UniqueId.random(), ref_Action_ID, ref_Id);
    }

    public static ProvidedOperationBody create( Sql context, UniqueId instanceId, UniqueId ref_Action_ID, UniqueId ref_Id ) throws XtumlException {
        ProvidedOperationBody newProvidedOperationBody = new ProvidedOperationBodyImpl( context, instanceId, ref_Action_ID, ref_Id );
        if ( context.addInstance( newProvidedOperationBody ) ) {
            return newProvidedOperationBody;
        }
        else throw new InstancePopulationException( "Instance already exists within this population." );
    }



    // attributes
    private UniqueId ref_Action_ID;
    @Override
    public void setAction_ID(UniqueId ref_Action_ID) throws XtumlException {
        checkLiving();
        if (ref_Action_ID.inequality( this.ref_Action_ID)) {
            final UniqueId oldValue = this.ref_Action_ID;
            this.ref_Action_ID = ref_Action_ID;
            getRunContext().addChange(new AttributeChangedDelta(this, KEY_LETTERS, "ref_Action_ID", oldValue, this.ref_Action_ID));
        }
    }
    @Override
    public UniqueId getAction_ID() throws XtumlException {
        checkLiving();
        return ref_Action_ID;
    }
    private UniqueId ref_Id;
    @Override
    public UniqueId getId() throws XtumlException {
        checkLiving();
        return ref_Id;
    }
    @Override
    public void setId(UniqueId ref_Id) throws XtumlException {
        checkLiving();
        if (ref_Id.inequality( this.ref_Id)) {
            final UniqueId oldValue = this.ref_Id;
            this.ref_Id = ref_Id;
            getRunContext().addChange(new AttributeChangedDelta(this, KEY_LETTERS, "ref_Id", oldValue, this.ref_Id));
        }
    }


    // instance identifiers
    @Override
    public IInstanceIdentifier getId1() {
        try {
            return new InstanceIdentifier(getAction_ID());
        }
        catch ( XtumlException e ) {
            getRunContext().getLog().error(e);
            System.exit(1);
            return null;
        }
    }

    // operations


    // static operations


    // events


    // selections
    private ProvidedOperation R687_specifies_processing_for_ProvidedOperation_inst;
    @Override
    public void setR687_specifies_processing_for_ProvidedOperation( ProvidedOperation inst ) {
        R687_specifies_processing_for_ProvidedOperation_inst = inst;
    }
    @Override
    public ProvidedOperation R687_specifies_processing_for_ProvidedOperation() throws XtumlException {
        return R687_specifies_processing_for_ProvidedOperation_inst;
    }
    private Body R698_is_a_Body_inst;
    @Override
    public void setR698_is_a_Body( Body inst ) {
        R698_is_a_Body_inst = inst;
    }
    @Override
    public Body R698_is_a_Body() throws XtumlException {
        return R698_is_a_Body_inst;
    }


    @Override
    public IRunContext getRunContext() {
        return context().getRunContext();
    }

    @Override
    public Sql context() {
        return context;
    }

    @Override
    public String getKeyLetters() {
        return KEY_LETTERS;
    }

    @Override
    public ProvidedOperationBody self() {
        return this;
    }

    @Override
    public ProvidedOperationBody oneWhere(IWhere<IXtumlType> condition) throws XtumlException {
        if (null == condition) throw new XtumlException("Null condition passed to selection.");
        if (condition.evaluate(this)) return this;
        else return EMPTY_PROVIDEDOPERATIONBODY;
    }

}

class EmptyProvidedOperationBody extends ModelInstance<ProvidedOperationBody,Sql> implements ProvidedOperationBody {

    // attributes
    public void setAction_ID( UniqueId ref_Action_ID ) throws XtumlException {
        throw new EmptyInstanceException( "Cannot set attribute of empty instance." );
    }
    public UniqueId getAction_ID() throws XtumlException {
        throw new EmptyInstanceException( "Cannot get attribute of empty instance." );
    }
    public UniqueId getId() throws XtumlException {
        throw new EmptyInstanceException( "Cannot get attribute of empty instance." );
    }
    public void setId( UniqueId ref_Id ) throws XtumlException {
        throw new EmptyInstanceException( "Cannot set attribute of empty instance." );
    }


    // operations


    // selections
    @Override
    public ProvidedOperation R687_specifies_processing_for_ProvidedOperation() {
        return ProvidedOperationImpl.EMPTY_PROVIDEDOPERATION;
    }
    @Override
    public Body R698_is_a_Body() {
        return BodyImpl.EMPTY_BODY;
    }


    @Override
    public String getKeyLetters() {
        return ProvidedOperationBodyImpl.KEY_LETTERS;
    }

    @Override
    public ProvidedOperationBody self() {
        return this;
    }

    @Override
    public boolean isEmpty() {
        return true;
    }

    @Override
    public ProvidedOperationBody oneWhere(IWhere<IXtumlType> condition) throws XtumlException {
        if (null == condition) throw new XtumlException("Null condition passed to selection.");
        return ProvidedOperationBodyImpl.EMPTY_PROVIDEDOPERATIONBODY;
    }

}
